==> checkstyle-1.17-sources.jar: hudson/plugins/checkstyle/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.checkstyle;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = new ResourceBundleHolder(Messages.class);

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String Checkstyle_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Checkstyle: %d warnings found (%d %s, %d %s, %d %s).
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportMultipleItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportMultipleItem");
    }

    /**
     * Checkstyle: %d warnings found (%d %s, %d %s, %d %s).
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportMultipleItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportMultipleItem");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String Checkstyle_ResultAction_OneNoHighScore() {
        return holder.format("Checkstyle.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneNoHighScore");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String Checkstyle_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("Checkstyle.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * in 1 Checkstyle file.
     * 
     */
    public static String Checkstyle_ResultAction_OneFile() {
        return holder.format("Checkstyle.ResultAction.OneFile");
    }

    /**
     * in 1 Checkstyle file.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFile() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFile");
    }

    /**
     * Publish Checkstyle Analysis Results
     * 
     */
    public static String Checkstyle_Publisher_Name() {
        return holder.format("Checkstyle.Publisher.Name");
    }

    /**
     * Publish Checkstyle Analysis Results
     * 
     */
    public static Localizable _Checkstyle_Publisher_Name() {
        return new Localizable(holder, "Checkstyle.Publisher.Name");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Checkstyle_ResultAction_OneFixedWarning() {
        return holder.format("Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static String Checkstyle_Trend_Name() {
        return holder.format("Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static Localizable _Checkstyle_Trend_Name() {
        return new Localizable(holder, "Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_Detail_header() {
        return holder.format("Checkstyle.Detail.header");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_Detail_header() {
        return new Localizable(holder, "Checkstyle.Detail.header");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_ProjectAction_Name() {
        return holder.format("Checkstyle.ProjectAction.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_ProjectAction_Name() {
        return new Localizable(holder, "Checkstyle.ProjectAction.Name");
    }

    /**
     *  1 new warning
     * 
     */
    public static String Checkstyle_ResultAction_OneNewWarning() {
        return holder.format("Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static String Checkstyle_NewWarnings_Detail_header() {
        return holder.format("Checkstyle.NewWarnings.Detail.header");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_NewWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.NewWarnings.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String Checkstyle_ResultAction_OneWarning() {
        return holder.format("Checkstyle.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneWarning");
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since yesterday!
     * 
     */
    public static String Checkstyle_ResultAction_OneHighScore() {
        return holder.format("Checkstyle.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since yesterday!
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneHighScore() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneHighScore");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since {0} days!
     * 
     */
    public static String Checkstyle_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since {0} days!
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * in {0} Checkstyle files.
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} Checkstyle files.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Checkstyle: 1 warning found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportSingleItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * Checkstyle: 1 warning found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static String Checkstyle_FixedWarnings_Detail_header() {
        return holder.format("Checkstyle.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.FixedWarnings.Detail.header");
    }

}

==> checkstyle-1.19-sources.jar: hudson/plugins/checkstyle/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.checkstyle;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = new ResourceBundleHolder(Messages.class);

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String Checkstyle_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Checkstyle.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Checkstyle: {0} warnings found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String Checkstyle_ResultAction_OneNoHighScore() {
        return holder.format("Checkstyle.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneNoHighScore");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String Checkstyle_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("Checkstyle.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * in 1 Checkstyle file.
     * 
     */
    public static String Checkstyle_ResultAction_OneFile() {
        return holder.format("Checkstyle.ResultAction.OneFile");
    }

    /**
     * in 1 Checkstyle file.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFile() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFile");
    }

    /**
     * Publish Checkstyle Analysis Results
     * 
     */
    public static String Checkstyle_Publisher_Name() {
        return holder.format("Checkstyle.Publisher.Name");
    }

    /**
     * Publish Checkstyle Analysis Results
     * 
     */
    public static Localizable _Checkstyle_Publisher_Name() {
        return new Localizable(holder, "Checkstyle.Publisher.Name");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Checkstyle_ResultAction_OneFixedWarning() {
        return holder.format("Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneFixedWarning");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static String Checkstyle_Trend_Name() {
        return holder.format("Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Trend
     * 
     */
    public static Localizable _Checkstyle_Trend_Name() {
        return new Localizable(holder, "Checkstyle.Trend.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_Detail_header() {
        return holder.format("Checkstyle.Detail.header");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_Detail_header() {
        return new Localizable(holder, "Checkstyle.Detail.header");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportNoItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle: no warnings found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportNoItem");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static String Checkstyle_ProjectAction_Name() {
        return holder.format("Checkstyle.ProjectAction.Name");
    }

    /**
     * Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_ProjectAction_Name() {
        return new Localizable(holder, "Checkstyle.ProjectAction.Name");
    }

    /**
     *  1 new warning
     * 
     */
    public static String Checkstyle_ResultAction_OneNewWarning() {
        return holder.format("Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneNewWarning");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static String Checkstyle_NewWarnings_Detail_header() {
        return holder.format("Checkstyle.NewWarnings.Detail.header");
    }

    /**
     * New Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_NewWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.NewWarnings.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String Checkstyle_ResultAction_OneWarning() {
        return holder.format("Checkstyle.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneWarning() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneWarning");
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since yesterday!
     * 
     */
    public static String Checkstyle_ResultAction_OneHighScore() {
        return holder.format("Checkstyle.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since yesterday!
     * 
     */
    public static Localizable _Checkstyle_ResultAction_OneHighScore() {
        return new Localizable(holder, "Checkstyle.ResultAction.OneHighScore");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since {0} days!
     * 
     */
    public static String Checkstyle_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no Checkstyle warnings since {0} days!
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * in {0} Checkstyle files.
     * 
     */
    public static String Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} Checkstyle files.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static String Checkstyle_ResultAction_HealthReportSingleItem() {
        return holder.format("Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * Checkstyle: one warning found.
     * 
     */
    public static Localizable _Checkstyle_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Checkstyle.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Checkstyle_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Checkstyle.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static String Checkstyle_FixedWarnings_Detail_header() {
        return holder.format("Checkstyle.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Checkstyle Warnings
     * 
     */
    public static Localizable _Checkstyle_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Checkstyle.FixedWarnings.Detail.header");
    }

}
